/*------------------------------------------------------------------------------
--  This file is a part of the libuc, microcontroler library
--  Copyright (C) 2011, Alexis Jeandet
--
--  This program is free software; you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation; either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program; if not, write to the Free Software
--  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
-------------------------------------------------------------------------------
--                 Author : Alexis Jeandet
--                   Mail : alexis.jeandet@member.fsf.org
-------------------------------------------------------------------------------*/
#ifndef BSP_H
#define BSP_H
#include <gpio.h>
#include <spi.h>
#include <ili9328.h>
#include <genericLCD_Controler.h>
#include <sdcard-spi.h>
#include <terminal.h>
#include <sdcard.h>
#include <mbr.h>
#include <VS10XX.h>
#include <fat32.h>
#include <SDL.h>
#include <stdint.h>
#include <SDLCD.h>


#define __MAX_OPENED_FILES__ 4
#define __FS_ROOT_SIZE__ 4


#define LED1 PC15
#define LED2 PC14

#define BP3   PA0

#define LCD_RESET PD10
#define LCD_BACKL PE11

#define VS1053SPI    spi1
#define VS1053xCS    PA3
#define VS1053xRESET PA2
#define VS1053xDCS   PA4
#define VS1053DREQ   PA1
#define VS1053MISO   PA6
#define VS1053MOSI   PA7
#define VS1053SCK    PA5



#define SDCARD2SPI   spi3
#define SDCARD2CS    PB8
#define SDCARD2CD    PB9
#define SDCARD2MISO  PB4
#define SDCARD2MOSI  PB5
#define SDCARD2SCK   PB3

extern float VREF0;

extern uint32_t currentCpuFreq;
extern LCD_t lcd0;

extern volatile vs10XXDev audioCodec0;

extern sdcardDev sdcard2;
extern blkdevice sdcard2blkdev;
extern dikpartition sdcard2Part1;
extern FAT32fs sdcard2FAT32part1;
extern dikpartition sdcard2Part2;
extern FAT32fs sdcard2FAT32part2;
extern dikpartition sdcard2Part3;
extern FAT32fs sdcard2FAT32part3;
extern dikpartition sdcard2Part4;
extern FAT32fs sdcard2FAT32part4;

extern int bsp_init();

extern void bsp_GPIO_init();
extern void bsp_uart_init();
extern void bsp_iic_init();
extern void bsp_spi_init();
extern void bsp_SD_init();
extern void bsp_Audio_init();
extern void bsp_GTerm_init();
extern int bsp_FSMC_init();

/*  VS1053  */
extern void vs1052setXCS(char val);
extern void vs1052setXDCS(char val);
extern void vs1052setRST(char val);
extern int vs10XXDREQ();

/*   SD CARD */
void bsppowersdcard(char onoff);
char bspsdcardpresent();
void bspsdcardselect(char YESNO);
char bspsdcardwriteprotected();


void bsp_lcd0_write_reg(uint32_t reg,uint32_t data);
uint32_t bsp_lcd0_read_reg(uint32_t reg);
void bsp_lcd0_writeGRAM(void *buffer, uint32_t count);
void bsp_lcd0_readGRAM(void *buffer, uint32_t count);


extern void putpixel(SDL_Surface *surface, int x, int y, Uint32 pixel);
extern Uint32 getpixel(SDL_Surface *surface, int x, int y);

#endif



















